
const path = require('path')
const exec = require('child_process').exec

/**
 * binary文件位置信息
 * @type {{win32, darwin, linux}}
 */
const ADB_BINARY_FILE = {
  'win32': path.resolve(__dirname, 'bin/window/adb.exe'),
  'darwin': path.resolve(__dirname, 'bin/mac/adb'),
  'linux': path.resolve(__dirname, 'bin/linux/adb')
}

/**
 * 执行adb命令
 *
 * @param command {string} adb命令
 * @param option  {object} 配置exec启动进程的选项
 * @returns {Promise<String, Error>} 成功时返回stdout输出， 执行失败返回Error对象
 */
function execADBCommand (command, option) {
  let cmd = command.split(' ')
  const binFile = ADB_BINARY_FILE[process.platform]
  cmd[0] = binFile
  cmd = cmd.join(' ')

  return new Promise((resolve, reject) => {
    exec(cmd, option || { 'stdio': 'inherit' }, (err, stdout, stderr) => {
      if (err) {
        reject(err)
      }
      resolve(stdout)
    })
  }).catch(err => {
    return err
  })
}

module.exports = {
  'exec': execADBCommand
}
